@@ -251,6 +251,19 @@ def sort_component_list(components):
     return slot_extensions
 
 
+def sort_slots(slots):
+
+    if slots.__len__() == 0:
+        return slots
+
+    if not all(slots[0].SlotBase == x.SlotBase for x in slots):
+        raise TypeError(f'List elements do not have same slot')
+
+    slot_extensions = [int(x.SlotExtension) for x in slots]
+    return slot_extensions
+
+
+
 def sort_references(references):
 
     if references.__len__() == 0:
